util.periodic_repeat()

Tile a seasonal pattern to cover duration time steps.

Usage

util.periodic_repeat(
    x,
    duration,
    *,
    axis=-1,
)

Parameters

x: ArrayLike

Seasonal pattern; the repeated axis has length equal to the period. Accepts any array-like (e.g. a raw numpyro.sample draw).

duration: int

Target length along axis.

axis: int = -1
Axis to repeat along (defaults to -1).

Returns

Array
x periodically repeated to length duration along axis.